pub fn install_path_hook(finder: &PyAny, sys: &PyModule) -> PyResult<()>Expand description
Prepend a path hook to sys.path_hooks that works with OxidizedFinder.
sys must be a reference to the sys module.
pub fn install_path_hook(finder: &PyAny, sys: &PyModule) -> PyResult<()>Prepend a path hook to sys.path_hooks that works with OxidizedFinder.
sys must be a reference to the sys module.