pub struct OxidizedFinder { /* private fields */ }
Python type to import modules.

This type implements the importlib.abc.MetaPathFinder interface for finding/loading modules. It supports loading various flavors of modules, allowing it to be the only registered sys.meta_path importer.

Implementations

Construct an instance from a module and resources state.