pub struct OxidizedZipFinder { /* private fields */ }
A meta path finder that reads from zip archives.

Known incompatibilities with zipimporter:

  • ResourceReader interface not implemented.
  • ResourceLoader interface not implemented.
  • Bytecode isn’t validated.

Implementations

Construct a new instance from zip data.

Construct a new instance from a PyObject conforming to the buffer protocol.

Construct a new instance from a reader.

The full content of the reader will be read to an in-memory buffer.