Struct oxidized_importer::OxidizedFinder
source · [−]pub struct OxidizedFinder { /* private fields */ }Expand description
Python type to import modules.
This type implements the importlib.abc.MetaPathFinder interface for finding/loading modules. It supports loading various flavors of modules, allowing it to be the only registered sys.meta_path importer.
Implementations
sourceimpl OxidizedFinder
impl OxidizedFinder
sourcepub fn new_from_module_and_resources<'a>(
py: Python<'_>,
m: &PyModule,
resources_state: Box<PythonResourcesState<'a, u8>>,
importer_state_callback: Option<impl FnOnce(&mut ImporterState)>
) -> PyResult<OxidizedFinder>
pub fn new_from_module_and_resources<'a>(
py: Python<'_>,
m: &PyModule,
resources_state: Box<PythonResourcesState<'a, u8>>,
importer_state_callback: Option<impl FnOnce(&mut ImporterState)>
) -> PyResult<OxidizedFinder>
Construct an instance from a module and resources state.